Class: Twitter::Entity::Symbol
- Inherits:
-
Twitter::Entity
- Object
- Base
- Twitter::Entity
- Twitter::Entity::Symbol
- Defined in:
- lib/twitter/entity/symbol.rb
Overview
Represents a Twitter cashtag symbol entity
Instance Attribute Summary collapse
-
#text ⇒ String
readonly
The text of the cashtag without the dollar sign.
Attributes inherited from Twitter::Entity
Attributes inherited from Base
Method Summary
Methods inherited from Base
#[], attr_reader, define_attribute_method, define_predicate_method, define_uri_method, display_uri_attr_reader, #initialize, object_attr_reader, predicate_attr_reader, uri_attr_reader
Methods included from Utils
Constructor Details
This class inherits a constructor from Twitter::Base
Instance Attribute Details
#text ⇒ String (readonly)
The text of the cashtag without the dollar sign
13 14 15 |
# File 'lib/twitter/entity/symbol.rb', line 13 def text @text end |