Class: Twitter::Variant
Overview
Represents a video variant with a specific bitrate and format
Instance Attribute Summary collapse
-
#bitrate ⇒ Integer
readonly
The bitrate of this variant in bits per second.
-
#content_type ⇒ String
readonly
The content type (MIME type) of this variant.
Attributes inherited from Base
Method Summary
Methods inherited from Base
#[], attr_reader, define_attribute_method, define_predicate_method, define_uri_method, display_uri_attr_reader, #initialize, object_attr_reader, predicate_attr_reader, uri_attr_reader
Methods included from Utils
Constructor Details
This class inherits a constructor from Twitter::Base
Instance Attribute Details
#bitrate ⇒ Integer (readonly)
The bitrate of this variant in bits per second
12 13 14 |
# File 'lib/twitter/variant.rb', line 12 def bitrate @bitrate end |
#content_type ⇒ String (readonly)
The content type (MIME type) of this variant
20 21 22 |
# File 'lib/twitter/variant.rb', line 20 def content_type @content_type end |